# covid-19-vaccination-vs.-mortality
世界各国のコロナワクチン接種率と新規死亡者数を可視化し、相関係数を出力する

## Data
Kaggle, Sina Karaji, [COVID vaccination vs. mortality]
https://www.kaggle.com/sinakaraji/covid-vaccination-vs-death

## How to install
$pip install vaccinationvsdeath

## How to run
$vaccinationvsdeath

enter the iso code
